pub struct Initialized { /* private fields */ }
Available on crate feature initialized only.
Tracks process initialization

Grants handles to components that need to be initialized and then waits for all handles to be dropped to signal readiness.

Implementations

Creates a new Handle for a component to be dropped when the component has been initialized

Waits for all handles to be dropped